==> lxqt-panel_1.2.0.orig.tar.xz: lxqt-panel-1.2.0/plugin-customcommand/translations/customcommand_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Gebruik het standaardpictogram of kies een bestand</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uitvoeren met ‘bash -c’</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Kies een lettertype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Opdracht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>%1 gebruiken om uitvoer te tonen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Pictogram</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatisch draaien als het paneel verticaal is</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo instellen…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Uit te voeren opdracht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Max. breedte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Opdracht herhalen na:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> second(en)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Muisopdrachten</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Klikken</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Omhoogscrollen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Omlaagscrollen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation>Kies een pictogrambestand</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Afbeeldingen (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.1.3.orig.tar.xz: lxqt-panel-2.1.3/plugin-customcommand/translations/customcommand_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="186"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Use icon from theme or browse file</source>
        <translation>Gebruik het standaardpictogram of kies een bestand</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uitvoeren met ‘bash -c’</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Select Font</source>
        <translation>Kies een lettertype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
        <source>Command</source>
        <translation>Opdracht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use %1 to display command output</source>
        <translation>%1 gebruiken om uitvoer te tonen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
        <source>Icon</source>
        <translation>Pictogram</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatisch draaien als het paneel verticaal is</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
        <source>echo Configure...</source>
        <translation>echo instellen…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Command to run</source>
        <translation>Uit te voeren opdracht</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
        <source>Max Width</source>
        <translation>Max. breedte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
        <source>Repeat command after:</source>
        <translation>Opdracht herhalen na:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
        <source> second(s)</source>
        <translation> second(en)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
        <source>Command outputs an image</source>
        <translation>Opdracht geeft een afbeelding als resultaat</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
        <source>Mouse Commands</source>
        <translation>Muisopdrachten</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source>Click</source>
        <translation>Klikken</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
        <source>Wheel Up</source>
        <translation>Omhoogscrollen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
        <source>Wheel Down</source>
        <translation>Omlaagscrollen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Select Icon File</source>
        <translation>Kies een pictogrambestand</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Afbeeldingen (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
